@@ -11,8 +11,8 @@ var indexSectionsWithContent =
   8: "_abcdefhilmnopqrstuvwz",
   9: "abcdeghilmnpstvwz",
   10: "_abcdfilmnorstuwz",
-  11: "bpvz",
-  12: "dot"
+  11: "abchpsvwz",
+  12: "dlot"
 };
 
 var indexSectionNames =
